import requests


def requests_linker(url,head):
    try:
        res = requests.get(url,headers=head)
        st_code = str(res.status_code)
        if st_code.startswith('2'):
            content = res.content
            return content
        else:
            return None
    except Exception as e:
        print('except:',e.args)
        return None




from abc import abstractmethod
from urllib.parse import urlparse
from fatkun.url_lib import url_gen,content_gen


class Converter:
    def __init__(self):
        self.head = {}
        self.url = ''
        self.file_type = ''
        self.file_name = ''


    @abstractmethod
    def url_key_gen(self,url):
        pass
    @abstractmethod
    def gen_file_name(self,url):
        pass

    def pre_url_process(self,url,file_type):
        parsed = urlparse(url)
        hostname = parsed.hostname
        if 'xhscdn' in hostname:
            self.url,self.file_type = url_gen(url)
        else:
            self.url = url
        self.file_name = self.gen_file_name(url)

    def file_convert(self,content,url,file_type):
        content,url = content_gen(content,url,file_type)
        return content,url





from fatkun import Fatkun


fatkun = Fatkun()
url = 'http://sns-na-i2.xhscdn.com/1040g00831g8rgina1u004b43duem6ilnicrgu98?imageView2/2/w/540/format/heif/q/46;imageMogr2/strip&redImage/frame/0&ap=11&sc=HF_PRV'
fatkun.pre_url_process(url, 'heif')
content = fatkun.get_requests()
file_dir = r'D:\files\example'
fatkun.save_file(content, file_dir)


import hashlib
import os.path

import requests
from fatkun.converter import Converter


class Fatkun(Converter):
    def __init__(self):
        super().__init__()
        self.head = {'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/135.0.0.0 Safari/537.36'}


    def url_key_gen(self,url):
        return super().url_key_gen(url)

    def gen_file_name(self,url):
        file_name = hashlib.md5(url.encode('utf8')).hexdigest()
        if 'xhscdn' in url:
            file_name = file_name + self.file_type
        elif 'xiaohongshu' in url:
            file_name = file_name + self.file_type
        else:
            file_name = file_name + self.file_type
        return file_name

    def get_requests(self):
        try:
            res = requests.get(url = self.url,headers=self.head)
            st_code = str(res.status_code)
            if st_code.startswith('2'):
                content = res.content
                return content
            else:
                return None
        except Exception as e:
            print('except:',e.args)
            return None

    def save_file(self,content,file_dir):
        content,url = self.file_convert(content,self.url,self.file_type)
        if content:
            file_pth = os.path.join(file_dir,self.file_name)
            print('文件保存路径：',file_pth)
            f = open(file_pth,'wb')
            f.write(content)
            f.close()
        else:
            print('内容为空未保存')



